package com.mjitech.qa.test;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import org.apache.http.client.ClientProtocolException;
import org.testng.Assert;
import org.testng.annotations.Test;

import com.mjitech.qa.data.MicroMedineceData;
import com.mjitech.qa.model.OrderData;
import com.mjitech.qa.model.RequestData;
import com.mjitech.qa.service.BaseService;

import net.sf.json.JSONObject;
public class MicroMedinece {
	BaseService service = new BaseService();
	JSONObject json = JSONObject.fromObject("{}");	
	private String skuId;
	private String quantity ;
	private String requestId ;
	public String getSkuId() {
		return skuId;
	}

	public void setSkuId(String skuId) {
		this.skuId = skuId;
	}

	public String getQuantity() {
		return quantity;
	}

	public void setQuantity(String quantity) {
		this.quantity = quantity;
	}

	public String getRequestId() {
		return requestId;
	}

	public void setRequestId(String requestId) {
		this.requestId = requestId;
	}

	private String orderNumber ;
	
	public String getOrderNumber() {
		return orderNumber;
	}

	public void setOrderNumber(String orderNumber) {
		this.orderNumber = orderNumber;
	}

	/**
	 * 下单(执行完之后，订单状态是待支付)-管
	 * @param skuId
	 * @param skuCount
	 * @param price
	 * @param warehouseId
	 * @param tokenId
	 * @date 2020-4-20   2073
	 * @result {"code":"200","message":"成功","success":true},"data":{"orderNumber":"S6845845536"}}
	 * 已下单：{"meta":{"code":"200","message":"已下过单","success":false},"data":null}
	 * {"meta":{"code":"200","message":"成功","success":true},"data":{"orderNumber":"S3512861729"}}
	 * */
	@Test(dataProvider="add_orderAction",dataProviderClass=MicroMedineceData.class)
	public void add_orderAction(int warehouseId,String tokenId) {
		List<OrderData> list = new ArrayList<OrderData>();
		OrderData orderData1 = new OrderData();
		OrderData orderData2 = new OrderData();
		//第一个商品
		orderData1.setPrice(0.01);
		orderData1.setSkuCount(3);
		orderData1.setSkuId(589);
		
		//多个商品
		orderData2.setPrice(0.01);
		orderData2.setSkuCount(3);
		orderData2.setSkuId(590);
		
		list.add(orderData1);
		list.add(orderData2);
		
		String url = "https://test.mjitech.com/web/weiyi_api/add_order.action?supplierId=wy001" ;
		json.put("warehouseId", warehouseId);
		json.put("tokenId",tokenId);//第三方提供
		json.put("orderData",list);
		try {
			JSONObject result = service.httppostMicroMedineceReturnJson(url,json.toString(),"add_order.action");
			String code = result.getJSONObject("meta").getString("code");
			String message = result.getJSONObject("meta").getString("message");
			String success = result.getJSONObject("meta").getString("success");	
			orderNumber = result.getJSONObject("data").getString("orderNumber");
			this.setOrderNumber(orderNumber);
			if("200".equals(code)) {
				Assert.assertEquals(code, "200");	
				Assert.assertEquals(message, "成功");
				Assert.assertEquals(success, "true");
			}					
			System.out.println("下单接口："+result);
		} catch (ClientProtocolException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}		
	}
    
	
	/**
	 * 支付成功(支付成功未取货状态)-管
	 * @param orderNumber 订单编号
	 * @author gangwang 
	 * @date 2020-04-20
	 * @result {"meta":{"code":"200","message":"成功","success":true},"data":{"takeUrl":"https://open.weixin.qq.com/connect/oauth2/authorize?appid=wx0aea8f497e298646&redirect_uri=https%3A%2F%2Ftest.mjitech.com%2Fweb%2Fwxauthorize.action&response_type=code&scope=snsapi_base&state=taking_goods_2466346688#wechat_redirect"}}
	 * S0224224359
	 * {"meta":{"code":"200","message":"成功","success":true},"data":{"takeUrl":"https://open.weixin.qq.com/connect/oauth2/authorize?appid=wx0aea8f497e298646&redirect_uri=https%3A%2F%2Ftest.mjitech.com%2Fweb%2Fwxauthorize.action&response_type=code&scope=snsapi_base&state=taking_goods_9347979663#wechat_redirect"}}
	 * */
	@Test(dependsOnMethods="add_orderAction")
	public void pay_successAction() {
		String url = "https://test.mjitech.com/web/weiyi_api/pay_success.action?supplierId=wy001" ;
		orderNumber = this.getOrderNumber();
		json.put("orderNumber", orderNumber);
		try {
			JSONObject result = service.httppostMicroMedineceReturnJson(url,json.toString(),"pay_success.action");
			String code = result.getJSONObject("meta").getString("code");
			String message = result.getJSONObject("meta").getString("message");
			boolean success = result.getJSONObject("meta").getBoolean("success");
			if("200".equals(code)) {
				Assert.assertEquals(code, "200");
				Assert.assertEquals(message, "成功");
				Assert.assertEquals(success, true);
			} 		
			System.out.println("pay_successAction：" + result);
		} catch (ClientProtocolException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}		
	}
	
	/**
	 * 获取订单的订单状态及实际出货信息-贾
	 * @param warehouseId 机器id
	 * @param orderNumber 订单编号
	 * @author gangwang
	 * @date 2020-04-20
	 * @result 1)已支付未出货{"meta":{"code":"200","message":"成功","success":true},"data":{"outBatchSkuList":[],"orderStatus":"未取货"}}
	 * 2)已出货{"meta":{"code":"200","message":"成功","success":true},"data":{"outBatchSkuList":[{"id":112383,"begin":0,"perpage":0,"sort":null,"sortDir":null,"creator":0,"updator":0,"createDatetime":1582194369000,"updateDatetime":1582194390000,"deleteMark":0,"sellOrderId":84720,"sellOrderSkuId":123343,"sellOrder":null,"outBatchId":69655,"originalBatchSkuId":0,"skuId":2243,"count":1,"outStatus":3,"outStatusDesc":"已出货","sellOrderSku":null,"skuPassEntityId":104223,"skuPassVo":null,"sku":null,"allOriginalOutBatchSkus":null,"exchangedSellOrderId":0,"realPrice":0,"isPresent":0,"activityType":"","activityId":0}],"orderStatus":"已取货"}}
	 *{"meta":{"code":"200","message":"成功","success":true},"data":{"outBatchSkuList":[{"id":112383,"begin":0,"perpage":0,"sort":null,"sortDir":null,"creator":0,"updator":0,"createDatetime":1582194369000,"updateDatetime":1582194390000,"deleteMark":0,"sellOrderId":84720,"sellOrderSkuId":123343,"sellOrder":null,"outBatchId":69655,"originalBatchSkuId":0,"skuId":2243,"count":1,"outStatus":3,"outStatusDesc":"已出货","sellOrderSku":null,"skuPassEntityId":104223,"skuPassVo":null,"sku":null,"allOriginalOutBatchSkus":null,"exchangedSellOrderId":0,"realPrice":0,"isPresent":0,"activityType":"","activityId":0}],"orderStatus":"已取消"}}
	 * */
	@Test(dependsOnMethods="pay_successAction",dataProvider="get_out_batchAction",dataProviderClass=MicroMedineceData.class)
	public void get_out_batchAction(int warehouseId,String orderNumber) {
		String url = "https://test.mjitech.com/web/weiyi_api/get_out_batch.action?supplierId=wy001" ;
		json.put("warehouseId", warehouseId);
		json.put("orderNumber", orderNumber);
		try {
			JSONObject result = service.httppostMicroMedineceReturnJson(url,json.toString(),"get_out_batch.action");
			String code = result.getJSONObject("meta").getString("code");
			String message = result.getJSONObject("meta").getString("message");
			boolean success = result.getJSONObject("meta").getBoolean("success");	
			if("200".equals(code)) {
				Assert.assertEquals(code, "200");	
				Assert.assertEquals(message, "成功");
				Assert.assertEquals(success, true);
			}
			System.out.println("获取订单的订单状态及实际出货信息："+result);
		} catch (ClientProtocolException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}		
		
	}
	
	/**
	 * 取消订单（ 取消恢复可售，订单状态变为已取消）-管
	 * @param orderNumber 订单编号
	 * @author gangwang
	 * @date 2020-04-20
	 * @result {"meta":{"code":"200","message":"成功","success":true},"data":true} 
	 * */
    @Test(dependsOnMethods="get_out_batchAction",dataProvider="cancel_orderAction",dataProviderClass=MicroMedineceData.class)
	public void cancel_orderAction(int warehouseId,String orderNumber) {
		String url = "https://test.mjitech.com/web/weiyi_api/cancel_order.action?supplierId=wy001" ;
		json.put("warehouseId", warehouseId);
		json.put("orderNumber",this.getOrderNumber());
		try {
			JSONObject result = service.httppostMicroMedineceReturnJson(url,json.toString(),"cancel_order.action");
			String code = result.getJSONObject("meta").getString("code");	
			String message = result.getJSONObject("meta").getString("message");	
			boolean success = result.getJSONObject("meta").getBoolean("success");
			if("200".equals(code)) {
				Assert.assertEquals(code, "200");
				Assert.assertEquals(message, "成功");
				Assert.assertEquals(success, true);
			}			
			System.out.println("获取订单的订单状态及实际出货信息："+result);
		} catch (ClientProtocolException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
	}
	
	
	/**
	 * 获取门店补货明细接口-管勇志
	 * @author gangwang
	 * @date 2020-04-17
	 * {"meta":{"code":"200","message":"成功","success":true},"data":[{"businessCode":"00039120001","list":[{"excepId":0,"taskDetailId":36642,"skuId":1666,"skuName":"可口可乐","skupassNo":"39_5_3_1","oldQuantity":90,"addrCount":2,"newQuantity":92,"excepCount":4,"status":"异常","addrDate":1588063177000,"addrDateStr":"2020-04-28 16:39:37","deliExc":561}]}]}
	 * **/
	@Test(dependsOnMethods="cancel_orderAction",dataProvider="get_finish_addrAction",dataProviderClass=MicroMedineceData.class)
	public void get_finish_addrAction(int warehouseId, String fromDate,String toDate) {
		String url = "http://test.mjitech.com/web/weiyi_api/get_finish_addr.action?supplierId=wy001" ;
		json.put("warehouseId", warehouseId);
		json.put("fromDate",fromDate);
		json.put("toDate",toDate);
		try {
			JSONObject result = service.httppostMicroMedineceReturnJson(url,json.toString(),"get_finish_addr.action");
			String code = result.getJSONObject("meta").getString("code");		
			String message = result.getJSONObject("meta").getString("message");
			boolean success = result.getJSONObject("meta").getBoolean("success");
			if("200".equals(code)) {
				Assert.assertEquals(code, "200");
				Assert.assertEquals(message, "成功");
				Assert.assertEquals(success, true);
			}
			System.out.println("获取门店补货明细接口"+result);
		} catch (ClientProtocolException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}		
	}
	
	
	/**
	 * 获取当前门店商品库存信息-贾碧霄
	 * @param warehouseId 机器id
	 * @param skuId  skuID(商品id) 选填（如果填了skuid则查询当前sku库存，否则查询当前门店所有sku库存信息）
	 * @author gangwang
	 * @date 2020-04-20
	 * {"meta":{"code":"200","message":"系统错误,请稍后再试","success":false},"data":null}
	 * {"meta":{"code":"200","message":"成功","success":true},"data":[{"skuId":2068,"skuName":"梁丰牌麦丽素","quantity":0,"realQuantity":1}]}
	 * */
	@Test(dependsOnMethods="get_finish_addrAction",dataProvider="get_inventoryAction",dataProviderClass=MicroMedineceData.class)
	public void get_inventoryAction(int warehouseId,int skuId) {
		String url = "http://test.mjitech.com/web/weiyi_api/get_inventory.action?supplierId=wy001" ;
		json.put("warehouseId", warehouseId);
		json.put("skuId",skuId);
		try {
			JSONObject result = service.httppostMicroMedineceReturnJson(url,json.toString(),"get_inventory.action");
			System.out.println(result);
		} catch (ClientProtocolException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}	
	}
	
	/**
	 * 获取门店补货请求接口（未处理状态下）
	 * @author gangwang
	 * @date 2020-04-17
	 * get_request_data.action:{"meta":{"code":"200","message":"成功","success":true},"data":[{"machineId":39,"vos":[{"skuId":2116,"quantity":1,"requestId":52486},{"skuId":2236,"quantity":2,"requestId":52523},{"skuId":578,"quantity":1,"requestId":52530},{"skuId":2407,"quantity":1,"requestId":52531},{"skuId":2326,"quantity":2,"requestId":52532},{"skuId":1074,"quantity":2,"requestId":52556},{"skuId":2375,"quantity":1,"requestId":52557},{"skuId":2066,"quantity":1,"requestId":52745},{"skuId":1679,"quantity":2,"requestId":52758},{"skuId":1680,"quantity":3,"requestId":52782},{"skuId":1071,"quantity":2,"requestId":52805},{"skuId":2225,"quantity":1,"requestId":52836},{"skuId":701,"quantity":1,"requestId":52837},{"skuId":783,"quantity":2,"requestId":52886},{"skuId":2463,"quantity":1,"requestId":52908},{"skuId":1686,"quantity":6,"requestId":53742},{"skuId":2027,"quantity":3,"requestId":53743},{"skuId":2243,"quantity":1,"requestId":53746},{"skuId":2521,"quantity":3,"requestId":53747},{"skuId":2520,"quantity":3,"requestId":53748},{"skuId":2068,"quantity":2,"requestId":53762},{"skuId":2187,"quantity":2,"requestId":53764},{"skuId":594,"quantity":3,"requestId":53765},{"skuId":2056,"quantity":2,"requestId":53766},{"skuId":1694,"quantity":5,"requestId":53767},{"skuId":1983,"quantity":3,"requestId":53769},{"skuId":969,"quantity":9,"requestId":53770},{"skuId":1666,"quantity":3,"requestId":53780},{"skuId":2290,"quantity":6,"requestId":53781},{"skuId":2293,"quantity":1,"requestId":53782}]}]}
	 * */
	@Test(dependsOnMethods="get_inventoryAction",dataProvider="get_request_data",dataProviderClass=MicroMedineceData.class)
	public void get_request_data(int[] warehouseIds) {
		String url = "http://test.mjitech.com/web/weiyi_api/get_request_data.action?supplierId=wy001" ;
		json.put("warehouseIds", warehouseIds);
		try {
			JSONObject result = service.httppostMicroMedineceReturnJson(url,json.toString(),"get_request_data.action");
			String code = result.getJSONObject("meta").getString("code");
			String message = result.getJSONObject("meta").getString("message");
			String success = result.getJSONObject("meta").getString("success");
//			String skuId = result.getJSONObject("data").getJSONObject("vos").getString("skuId");
//			String quantity  = result.getJSONObject("data").getJSONObject("vos").getString("quantity");
//			String requestId = result.getJSONObject("data").getJSONObject("vos").getString("requestId");
//			this.setSkuId(skuId);
//			this.setQuantity(quantity);
//			this.setRequestId(requestId);			
			if("200".equals(code)) {
				Assert.assertEquals(code, "200");
				Assert.assertEquals(message, "成功");
				Assert.assertEquals(success, "true");
			}
			System.out.println("获取补货请求接口" + result);
		} catch (ClientProtocolException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}		
	}
	
	/**
	 * 保存分拣单-管勇志
	 * @author gangwang
	 * @param requestId  补货请求id
	 * @param skuId   商品id
	 * @param requestQuantity 请求商品数量
	 * @param lotDate 批次日期
	 * @param deliveryId 配送单号
	 * @date 2020-04-20
	 * {"meta":{"code":"200","message":"成功","success":true},"data":true}
	 * {"meta":{"code":"200","message":"此补货请求状态不对或者没有此补货请求53756","success":false},"data":null}
	 * 
	 * 数据依托获取门店补货请求接口中接口返回的数据 get_request_data()
	 */
	@Test(dependsOnMethods="get_request_data",dataProvider="save_picking_dataAction",dataProviderClass=MicroMedineceData.class)	
	public void save_picking_dataAction(int requestId,int skuId, int requestQuantity,String lotDate,String deliveryId) {
		List<RequestData> list = new ArrayList<RequestData>() ;
		String url = "https://test.mjitech.com/web/weiyi_api/save_picking_data.action?supplierId=wy001" ;
		for (int i = 0; i < 1; i++) {
			RequestData data = new RequestData() ;
			data.setRequestId(requestId);
			data.setSkuId(skuId);
			data.setRequestQuantity(requestQuantity);
			data.setLotDate(lotDate);//第三给的
			list.add(data);
		}
		json.put("requestData", list);
		json.put("deliveryId",deliveryId);		//需要第三方提供
		try {
			JSONObject result = service.httppostMicroMedineceReturnJson(url,json.toString(),"save_picking_data.action");
			System.out.println(""+result);
		} catch (ClientProtocolException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
	
	/**
	 * 药品批次核对查看
	 * @param orderNumber 订单号
	 * @param batchId  
	 * */
//	@Test(dataProvider="check_batch_viewAction",dataProviderClass=MicroMedineceData.class)
	public void check_batch_viewAction(String orderNumber,String batchId) {
		String url = "https://test.mjitech.com/web/weiyi_api/check_batch_view.action?supplierId=wy001" ;		
		json.put("orderNumber", orderNumber);
		json.put("batchId",batchId);		
		try {
			JSONObject result = service.httppostMicroMedineceReturnJson(url,json.toString(),"check_batch_view.action");
			System.out.println(""+result);
		} catch (ClientProtocolException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	
	}
	
	/**
	 * 药品批次核对
	 * @param orderNumber 订单号
	 * @param batchId 出货批次ID
	 * */
//	@Test(dataProvider="check_batchAction",dataProviderClass=MicroMedineceData.class)
	public void check_batchAction(String orderNumnber,String batch) {
		String url = "https://test.mjitech.com/web/weiyi_api/check_batch.action?supplierId=wy001" ;
		json.put("orderNumber", orderNumnber);
		json.put("batchId",batch);		
		try {
			JSONObject result = service.httppostMicroMedineceReturnJson(url,json.toString(),"check_batch.action");
			System.out.println(""+result);
		} catch (ClientProtocolException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
	
	/**
	 * 微医渠道：全单退款-智
	 * {"meta":{"code":"200","message":"成功","success":true},"data":{"failedSkus":[],"status":"成功"}}
	 * @param orderNumber 订单号
	 * @author gangwang
	 * @data 2020-04-26
	 * */
	@Test(dependsOnMethods="save_picking_dataAction",dataProvider="refundAction",dataProviderClass=MicroMedineceData.class)
	public void refundAction(String orderNumber) {
		String url = "https://test.mjitech.com/web/weiyi_api/refund.action?supplierId=wy001" ;
		json.put("orderNumber", orderNumber);  
		try {
			JSONObject result = service.httppostMicroMedineceReturnJson(url,json.toString(),"refund.action");
			String code = result.getJSONObject("meta").getString("code");
			String message = result.getJSONObject("meta").getString("message");
			String success = result.getJSONObject("meta").getString("success");
			Assert.assertEquals(code, "200");
			if("200".equals(code)&& "成功".equals(message)) {
				Assert.assertEquals(message, "成功");
				Assert.assertEquals(success, "true");
			} else {
				Assert.assertEquals(message, "该渠道订单不可调用此接口");
				Assert.assertEquals(success, "false");
			}			
			System.out.println("微医渠道-退款"+result);
		} catch (ClientProtocolException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
	
	/**
	 *单个商品退款（订单状态为已取货，一单多个商品退款相当于退款接口）-智
	 *单个退款：S0224224359 {"meta":{"code":"200","message":"成功","success":true},"data":{"failedSkus":[],"status":"成功"}}
	 *@author gangwang
	 *@date 2020-04-28
	 * */
	@Test(dependsOnMethods="refundAction")
	public void refund_skuAction() {
		String url = "https://test.mjitech.com/web/weiyi_api/refund_sku.action?supplierId=wy001" ;
		json.put("orderNumber", "S0233195842");
		json.put("skuNumbers","UY000103,UY002585,UY002579");
		
		try {
			JSONObject result = service.httppostMicroMedineceReturnJson(url,json.toString(),"refund_sku.action");
			String code = result.getJSONObject("meta").getString("code");
			String message = result.getJSONObject("meta").getString("message");
			String success = result.getJSONObject("meta").getString("success");
			Assert.assertEquals(code, "200");
			if("200".equals(code)&& "成功".equals(message)) {
				Assert.assertEquals(message, "成功");				
				Assert.assertEquals(success, "true");
			} else {
				Assert.assertEquals(message, "该渠道订单不可调用此接口");
				Assert.assertEquals(success, "false");
			}			
			System.out.println("微医渠道-单个商品退款："+result);
		} catch (ClientProtocolException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
	}
	

}

